from .adjectives import ADJECTIVES
from .animals import ANIMALS
from .colors import COLORS
from .countries import COUNTRIES
from .languages import LANGUAGES
from .names import NAMES
from .star_wars import STAR_WARS


__all__ = [ADJECTIVES, ANIMALS, COLORS, COUNTRIES, LANGUAGES, NAMES, STAR_WARS]
